package com.ruoyi.project.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TpAreaOptionalPara;
import com.ruoyi.project.business.domain.TpAreaOptionalParaPrice;
import com.ruoyi.project.business.dto.TpAreaOptionalDTO;
import org.apache.ibatis.annotations.Param;

import java.util.List;
/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2024-05-28
 */
public interface TpAreaOptionalParaPriceMapper extends BaseMapper<TpAreaOptionalParaPrice>
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TpAreaOptionalParaPrice selectTpAreaOptionalParaPriceById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tpAreaOptionalParaPrice 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TpAreaOptionalParaPrice> selectTpAreaOptionalParaPriceList(TpAreaOptionalParaPrice tpAreaOptionalParaPrice);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tpAreaOptionalParaPrice 【请填写功能名称】
     * @return 结果
     */
    public int insertTpAreaOptionalParaPrice(TpAreaOptionalParaPrice tpAreaOptionalParaPrice);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tpAreaOptionalParaPrice 【请填写功能名称】
     * @return 结果
     */
    public int updateTpAreaOptionalParaPrice(TpAreaOptionalParaPrice tpAreaOptionalParaPrice);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTpAreaOptionalParaPriceById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTpAreaOptionalParaPriceByIds(Long[] ids);

    List<TpAreaOptionalDTO> listAllOptionParamInfoByElevatorModelId(Long elevatorModelId);

    void clearPrice(Long id);

    void deleteTpAreaOptionalParaPriceByElevatorModelId(@Param("id") Long id);
    int getOptionalParaPriceCountWithModel(@Param("ids") Long[] ids, @Param("elevatorModelId") Long elevatorModelId);

}
