package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.framework.annotation.DataUpdateCheck;
import com.ruoyi.project.business.domain.TpAreaOptionalPara;
import com.ruoyi.project.business.domain.TpAreaOptionalParaPrice;
import com.ruoyi.project.business.service.ITpAreaOptionalParaPriceService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-05-28
 */
@RestController
@RequestMapping("/business/areaOption/para/price")
public class TpAreaOptionalParaPriceController extends BaseController
{
    @Autowired
    private ITpAreaOptionalParaPriceService tpAreaOptionalParaPriceService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:price:list')")
    @GetMapping("/list")
    public TableDataInfo list(TpAreaOptionalParaPrice tpAreaOptionalParaPrice)
    {
        startPage();
        List<TpAreaOptionalParaPrice> list = tpAreaOptionalParaPriceService.selectTpAreaOptionalParaPriceList(tpAreaOptionalParaPrice);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:price:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpAreaOptionalParaPrice tpAreaOptionalParaPrice)
    {
        List<TpAreaOptionalParaPrice> list = tpAreaOptionalParaPriceService.selectTpAreaOptionalParaPriceList(tpAreaOptionalParaPrice);
        ExcelUtil<TpAreaOptionalParaPrice> util = new ExcelUtil<TpAreaOptionalParaPrice>(TpAreaOptionalParaPrice.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:price:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tpAreaOptionalParaPriceService.selectTpAreaOptionalParaPriceById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TpAreaOptionalParaPrice tpAreaOptionalParaPrice)
    {
        return toAjax(tpAreaOptionalParaPriceService.insertTpAreaOptionalParaPrice(tpAreaOptionalParaPrice));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    @DataUpdateCheck(key = "id", tableName = "tp_area_optional_para_price")
    public AjaxResult edit(@RequestBody TpAreaOptionalParaPrice tpAreaOptionalParaPrice)
    {
        return toAjax(tpAreaOptionalParaPriceService.updateTpAreaOptionalParaPrice(tpAreaOptionalParaPrice));
    }

    @Log(title = "【切换状态】", businessType = BusinessType.UPDATE)
    @PutMapping("toggleStatus")
    public AjaxResult toggleStatus(@RequestBody TpAreaOptionalParaPrice tpAreaOptionalParaPrice)
    {
        TpAreaOptionalParaPrice update = new TpAreaOptionalParaPrice();
        update.setId(tpAreaOptionalParaPrice.getId());
        update.setStatus(tpAreaOptionalParaPrice.getStatus());
        return toAjax(tpAreaOptionalParaPriceService.updateTpAreaOptionalParaPrice(update));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tpAreaOptionalParaPriceService.deleteTpAreaOptionalParaPriceByIds(ids));
    }
}
